"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = __importDefault(require("axios"));
const introspection_query_1 = __importDefault(require("./introspection-query"));
const resolverDeets_1 = require("./resolverDeets");
const pluralize_1 = __importDefault(require("pluralize"));
/**
 * Introspects the services and gets the data required for the modules functionality to run.
 */
exports.populateResolverDetails = async (services) => {
    await Promise.all(services.map(async (service) => {
        // introspect service
        const res = await axios_1.default({
            url: service.uri,
            method: 'post',
            data: {
                query: introspection_query_1.default,
            },
        });
        // map data to resolverMap
        res.data.data.__schema.types[0].fields.forEach((field) => {
            resolverDeets_1.resolverMap[field.name] = {
                serviceUrl: service.uri,
                returnType: field.type.kind === 'LIST' ? 'array' : 'object',
                nameAsSingular: pluralize_1.default(field.name, 1),
                groupArgs: field.args.map((arg) => {
                    if (arg.type.kind === 'LIST' && arg.type.ofType.name === 'Int') {
                        return arg.name;
                    }
                    return;
                }).filter((e) => !!e)
            };
        });
    }));
    console.log('resolverMap after populating: ', resolverDeets_1.resolverMap);
};
//# sourceMappingURL=populate.js.map