"use strict";
/**
 * THINGS TO TEST:
 * - different queries being passed into group-resolve
 * - importing of resovler data
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const proxyquire_1 = __importDefault(require("proxyquire"));
const mock_responses_1 = require("./mock-responses");
const resolverDeets_1 = require("../src/resolverDeets");
/**
 * Require group-resolve function with custom level on axios responses
 * - to count the requests sent
 * - to respond with the correct mocked data
 */
const customAxios = async (args) => {
    if (args.url === 'user') {
        serviceCalls.user++;
        return mock_responses_1.userResponses(args.data.query);
    }
    if (args.url === 'wallet') {
        serviceCalls.wallet++;
        return mock_responses_1.walletResponses(args.data.query);
    }
    throw new Error('args.url is not valid');
};
const sendReqs = proxyquire_1.default('../src/sendRequestsToServices', { axios: customAxios });
const groupResolve = proxyquire_1.default('../src/groupResolve', { './index': { isHub: true }, './sendRequestsToServices': sendReqs }).default;
/**
 * Mock resolverMap
 */
resolverDeets_1.resolverMap.users = { serviceUrl: 'user', returnType: 'array', nameAsSingular: 'user', groupArgs: [] };
resolverDeets_1.resolverMap.user = { serviceUrl: 'user', returnType: 'object', nameAsSingular: 'user', groupArgs: [] };
resolverDeets_1.resolverMap.wallet = { serviceUrl: 'wallet', returnType: 'object', nameAsSingular: 'wallet', groupArgs: ['userIds'] };
resolverDeets_1.resolverMap.wallets = { serviceUrl: 'wallet', returnType: 'array', nameAsSingular: 'wallet', groupArgs: [] };
resolverDeets_1.resolverMap.limit = { serviceUrl: 'wallet', returnType: 'object', nameAsSingular: 'limit', groupArgs: ['userIds'] };
resolverDeets_1.resolverMap.limits = { serviceUrl: 'wallet', returnType: 'array', nameAsSingular: 'limit', groupArgs: [] };
resolverDeets_1.resolverMap.comment = { serviceUrl: 'user', returnType: 'object', nameAsSingular: 'comment', groupArgs: [] };
resolverDeets_1.resolverMap.comments = { serviceUrl: 'user', returnType: 'array', nameAsSingular: 'comment', groupArgs: [] };
const schemas = {
    a: `{
    user(id:1) {
      id
      firstName
      lastName
    }
  }`,
    b: `{
    wallets {
      userId
      amount
    }
  }`,
    c: `{
    users {
      firstName
    }

    user(id: 1){
      firstName
    }

    wallets{
      userId
      amount
    }
  }`,
    d: `{
    users{
      id
      firstName
      lastName
      wallet {
        amount
      }
      limit {
        loss
        deposit
      }
    }
  }`,
    e: `{
    users {
      firstName
      lastName
      comments {
        id
        userId
        content
      }
    }
  }`,
};
const serviceCalls = {
    user: 0,
    wallet: 0,
};
describe('queries to default back to graphQL behaviour [not use group-resolve]', () => {
    beforeEach(() => {
        serviceCalls.user = 0;
        serviceCalls.wallet = 0;
    });
    it('query example a', async () => {
        let test = false;
        await groupResolve({ queryString: schemas.a }, () => {
            test = true;
        }, {});
        chai_1.expect(test).to.be.true;
    });
    it('query example b', async () => {
        let test = false;
        await groupResolve({ queryString: schemas.b }, () => {
            test = true;
        }, {});
        chai_1.expect(test).to.be.true;
    });
    it('query example c', async () => {
        let test = false;
        await groupResolve({ queryString: schemas.c }, () => {
            test = true;
        }, {});
        chai_1.expect(test).to.be.true;
    });
});
describe('queries to use group-resolve', () => {
    beforeEach(() => {
        serviceCalls.user = 0;
        serviceCalls.wallet = 0;
    });
    it('query example d', async () => {
        const res = await groupResolve({ queryString: schemas.d }, () => {
            throw new Error('OOPS');
        }, {});
        chai_1.expect(res).to.deep.equal({
            data: {
                users: [
                    {
                        id: 1,
                        firstName: 'Josh',
                        lastName: 'Kneale',
                        wallet: {
                            amount: 11,
                        },
                        limit: {
                            loss: 20,
                            deposit: 80,
                        },
                    },
                    {
                        id: 2,
                        firstName: 'Tony',
                        lastName: 'Stark',
                        wallet: {
                            amount: 100,
                        },
                        limit: {
                            loss: 45,
                            deposit: 100,
                        },
                    },
                    {
                        id: 3,
                        firstName: 'Bruce',
                        lastName: 'Banner',
                        wallet: {
                            amount: 60,
                        },
                        limit: {
                            loss: 12,
                            deposit: 15,
                        },
                    },
                ],
            },
        });
        chai_1.expect(serviceCalls.user).to.equal(1);
        chai_1.expect(serviceCalls.wallet).to.equal(1);
    });
    it('query example e', async () => {
        const res = await groupResolve({ queryString: schemas.e }, () => {
            throw new Error('OOPS');
        }, {});
        chai_1.expect(res).to.deep.equal({
            data: {
                users: [
                    {
                        firstName: 'Josh',
                        lastName: 'Kneale',
                        comments: [
                            {
                                id: 1,
                                userId: 1,
                                content: 'my comment',
                            },
                            {
                                id: 2,
                                userId: 1,
                                content: 'my other comment',
                            },
                        ],
                    },
                    {
                        firstName: 'Tony',
                        lastName: 'Stark',
                        comments: [
                            {
                                id: 3,
                                userId: 2,
                                content: 'test comment',
                            },
                        ],
                    },
                    {
                        firstName: 'Bruce',
                        lastName: 'Banner',
                        comments: [],
                    },
                ],
            },
        });
        chai_1.expect(serviceCalls.user).to.equal(1);
    });
});
//# sourceMappingURL=index.js.map